Model class abstract

Interface for models intended to be used with signal mechanism.

It is recommended to inherit from this class for easier usage of signals. Use Model.init and Model.dispose to do some work when the model is added to Store. You can as well use the Store to store, update, access and remove your models. In this case init and dispose will be called automatically when Store.add and Store.remove is used. See Store for more details.

Constructors

Model()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

bind<T extends Object>(T value, Signal signal) → T
Returns the value and also connects the signal to any Watcher that accessed this value.
dispose() → void
Cleans up when the model is removed from the Store.
init() → void
Does some work when the model is added to the Store.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited