get<T extends SignalModel> static method

T? get<T extends SignalModel>([
  1. String? id
])

Returns the model of given type from the store. Returns null if no such model exists. Use the id parameter to get an instance of id model. See ModelStore.add for details.

Implementation

static T? get<T extends SignalModel>([String? id]) {
  final key = id ?? T;
  return _EagerModelStore.get(key) ?? _LazyModelStore.get(key);
}