property library
Provides property functionality.
Classes
-
Property<
T extends Object> -
Class implementing property functionality.
A property is a combination of a value and a signal.
The property is useful when the model of the widget is too small.
In that case creating a property will be shorter.
Property contains a Property.changed signal which is emitted
automatically after setting
Property.valueor Property.update. It is best to use this in combination with PropertyWidget.
Extensions
- PropertyExtension on T
- Creates a property by appending property after a value. This is a shorter way for creating a property.