signal library

Signal helps you to establish communication between two entities.

Classes

Signal
Signals help you to establish connections between two entities.

Functions

connect(Signal signal, Function slot) → void
free floating connect function. Use it to connect a signal to a slot.
disconnect(Signal signal, Function slot) → void
free floating disconnect function. Use to disconnect a signal from a slot.

Typedefs

Slot = void
Helps visually distinguishing between slots and other methods. Not necessary to use but helpful for void slots. Slots must be a function with at most one argument.