onRebuild method
void
onRebuild()
This callback will be passed to setState when this widget is rebuilt due to signal emission.
Implementation
void onRebuild() {}
This callback will be passed to setState when this widget is rebuilt due to signal emission.
void onRebuild() {}