onDeactivate property
A callback which is called when the deactivate method of this widget's state is called.
Implementation
final VoidCallback? onDeactivate;
A callback which is called when the deactivate method of this widget's state is called.
final VoidCallback? onDeactivate;