remove<T extends Model> static method
Removes the model of given type from the store and returns it.
It also calls the dispose method of the model.
Returns null if no model is found.
Use the id parameter to remove an instance of id model.
See Store.add for details.
Implementation
static T? remove<T extends Model>([String? id]) {
final key = id ?? T;
_LazyModelStore.remove(key);
return _EagerModelStore.remove(key);
}