watch property
The builder for the widget that uses property inside itself.
Implementation
final Widget Function(BuildContext context) watch;
The builder for the widget that uses property inside itself.
final Widget Function(BuildContext context) watch;