addEager<T extends SignalModel> static method
Adds the model to the store immediately instead of lazily like ModelStore.add
Provide a unique string id to the optional id parameter to add more than one
instance of same model.
Implementation
static void addEager<T extends SignalModel>(T model, [String? id]) {
final key = id ?? T;
_EagerModelStore.add(model, key);
}