property_widget library
Provides property widget functionality.
Classes
-
Property<
T extends Object> -
Class implementing property functionality.
A property is a combination of a value and a signal.
The property is useful when the model of the widget is too small.
In that case creating a property will be shorter.
Property contains a Property.changed signal which is emitted
automatically after setting
Property.valueor Property.update. It is best to use this in combination with PropertyWidget. -
PropertyWidget<
T extends Object> - An Widget that accepts a property and automatically rebuilds when the property is changed by setting Property.value or calling Property.update method or the Property.changed signal is emitted by the user.
Extensions
- PropertyExtension on T
- Creates a property by appending property after a value. This is a shorter way for creating a property.