Signal class

The Signal class offering all the signal features.

Constructors

Signal()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call<T>([T? argument]) → void
Calls the slots connected with this signal. Optionally can pass an argument to the slot as well. If an argument is provided but the slot doesn't take one, then the argument is discarded and the slot is still called.
connect(Function slot) → void
in built connect function for object flavoured usage.
disconnect(Function slot) → void
in built disconnect function for object flavoured usage.
multiConnect(List<Function> slots) → void
in built multi connect for object flavoured usage.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited