call<T> method
void
call<T>([
- T? argument
Calls the slots connected with this signal. Optionally can pass an argument to the slot as well. If an argument is provided but the slot doesn't take one, then the argument is discarded and the slot is still called.
Implementation
void call<T>([T? argument]) {
_slotStore.sync(); // See the SlotStore class docs for explanation
_emit<T>(this, argument);
}