multiConnect function
free floating multi connect function. Use it to connect a list of slots to a signal. The speciality of this function is that the slots are guaranteed to be called in order. That is, if the list looks like {a,b,c}, slot 'a' will be called first, then 'b' and so on.
Implementation
void multiConnect(Signal signal, List<Function> slots) {
signal._slotStore.addMultiSlot(slots);
}