signal_model library
Signal model is the interface for your models.
Classes
- Signal
- The Signal class offering all the signal features.
- SignalModel
- Interface for models intended to be used with signal mechanism.
Functions
-
connect(
Signal signal, Function slot) → void - free floating connect function. Use it to connect a signal to a slot.
-
disconnect(
Signal signal, Function slot) → void - free floating disconnect function. Use to disconnect a signal from a slot.
-
multiConnect(
Signal signal, List< Function> slots) → void - free floating multi connect function. Use it to connect a list of slots to a signal. The speciality of this function is that the slots are guaranteed to be called in order. That is, if the list looks like {a,b,c}, slot 'a' will be called first, then 'b' and so on.
Typedefs
- Slot = void
- Signals help you to establish connections between two entities.