SignalModel class abstract
Interface for models intended to be used with signal mechanism.
It is recommended to implement or inherit from this class for easier usage of signals. The SignalModel.init and SignalModel.dispose must be called manually by the user at appropriate times, if it is not being used with a SignalWidget. You can as well use the ModelStore to store, update, access and remove your models. In this case init and dispose will be called automatically when ModelStore.add and ModelStore.remove is used. See ModelStore for more details.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void - Cleans up when the model is removed from the ModelStore.
-
init(
) → void - Does some work when the model is added to the ModelStore.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited