onActivate property
A callback which is called when this widget is reinserted into the tree after having been removed via deactivate method of the state object of this widget.
Implementation
final VoidCallback? onActivate;
A callback which is called when this widget is reinserted into the tree after having been removed via deactivate method of the state object of this widget.
final VoidCallback? onActivate;